"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.serverless.triggers.v1.trigger_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetTriggerRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TRIGGER_ID_FIELD_NUMBER: builtins.int
    trigger_id: builtins.str
    """ID of the trigger to return.

    To get a trigger ID make a [TriggerService.List] request.
    """
    def __init__(
        self,
        *,
        trigger_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["trigger_id", b"trigger_id"]) -> None: ...

global___GetTriggerRequest = GetTriggerRequest

@typing.final
class ListTriggersRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list triggers in.

    To get a folder ID use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than `pageSize`, the service returns a [ListTriggersResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.

    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `pageToken` to the
    [ListTriggersResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters triggers listed in the response.

    The expression must specify:
    1. The field name. Currently filtering can only be applied to the [Trigger.name] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    Example of a filter: `name=my-trigger`.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListTriggersRequest = ListTriggersRequest

@typing.final
class ListTriggersResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TRIGGERS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListTriggersRequest.page_size], use `nextPageToken` as the value
    for the [ListTriggersRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `nextPageToken` to continue paging through the results.
    """
    @property
    def triggers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.serverless.triggers.v1.trigger_pb2.Trigger]:
        """List of triggers in the specified folder."""

    def __init__(
        self,
        *,
        triggers: collections.abc.Iterable[yandex.cloud.serverless.triggers.v1.trigger_pb2.Trigger] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "triggers", b"triggers"]) -> None: ...

global___ListTriggersResponse = ListTriggersResponse

@typing.final
class CreateTriggerRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    RULE_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create a trigger in.

    To get a folder ID make a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    name: builtins.str
    """Name of the trigger.
    The name must be unique within the folder.
    """
    description: builtins.str
    """Description of the trigger."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs."""

    @property
    def rule(self) -> yandex.cloud.serverless.triggers.v1.trigger_pb2.Trigger.Rule:
        """Trigger type."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        rule: yandex.cloud.serverless.triggers.v1.trigger_pb2.Trigger.Rule | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["rule", b"rule"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "folder_id", b"folder_id", "labels", b"labels", "name", b"name", "rule", b"rule"]) -> None: ...

global___CreateTriggerRequest = CreateTriggerRequest

@typing.final
class CreateTriggerMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TRIGGER_ID_FIELD_NUMBER: builtins.int
    trigger_id: builtins.str
    """ID of the trigger that is being created."""
    def __init__(
        self,
        *,
        trigger_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["trigger_id", b"trigger_id"]) -> None: ...

global___CreateTriggerMetadata = CreateTriggerMetadata

@typing.final
class UpdateTriggerRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    TRIGGER_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    RULE_FIELD_NUMBER: builtins.int
    trigger_id: builtins.str
    """ID of the trigger to update.

    To get a trigger ID make a [TriggerService.List] request.
    """
    name: builtins.str
    """New name for the trigger.
    The name must be unique within the folder.
    """
    description: builtins.str
    """New description of the trigger."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which attributes of the trigger should be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Trigger labels as `key:value` pairs.

        Existing set of labels is completely replaced by the provided set, so if you just want
        to add or remove a label, request the current set of labels with a [TriggerService.Get] request.
        """

    @property
    def rule(self) -> yandex.cloud.serverless.triggers.v1.trigger_pb2.Trigger.Rule:
        """New parameters for trigger."""

    def __init__(
        self,
        *,
        trigger_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        rule: yandex.cloud.serverless.triggers.v1.trigger_pb2.Trigger.Rule | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["rule", b"rule", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "labels", b"labels", "name", b"name", "rule", b"rule", "trigger_id", b"trigger_id", "update_mask", b"update_mask"]) -> None: ...

global___UpdateTriggerRequest = UpdateTriggerRequest

@typing.final
class UpdateTriggerMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TRIGGER_ID_FIELD_NUMBER: builtins.int
    trigger_id: builtins.str
    """ID of the trigger that is being updated."""
    def __init__(
        self,
        *,
        trigger_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["trigger_id", b"trigger_id"]) -> None: ...

global___UpdateTriggerMetadata = UpdateTriggerMetadata

@typing.final
class DeleteTriggerRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TRIGGER_ID_FIELD_NUMBER: builtins.int
    trigger_id: builtins.str
    """ID of the trigger to delete.

    To get a trigger ID make a [TriggerService.List] request.
    """
    def __init__(
        self,
        *,
        trigger_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["trigger_id", b"trigger_id"]) -> None: ...

global___DeleteTriggerRequest = DeleteTriggerRequest

@typing.final
class DeleteTriggerMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TRIGGER_ID_FIELD_NUMBER: builtins.int
    trigger_id: builtins.str
    """ID of the trigger that is being deleted."""
    def __init__(
        self,
        *,
        trigger_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["trigger_id", b"trigger_id"]) -> None: ...

global___DeleteTriggerMetadata = DeleteTriggerMetadata

@typing.final
class PauseTriggerRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TRIGGER_ID_FIELD_NUMBER: builtins.int
    trigger_id: builtins.str
    """ID of the trigger to pause

    To get a trigger ID make a [TriggerService.List] request.
    """
    def __init__(
        self,
        *,
        trigger_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["trigger_id", b"trigger_id"]) -> None: ...

global___PauseTriggerRequest = PauseTriggerRequest

@typing.final
class PauseTriggerMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TRIGGER_ID_FIELD_NUMBER: builtins.int
    trigger_id: builtins.str
    """ID of the trigger that is being paused."""
    def __init__(
        self,
        *,
        trigger_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["trigger_id", b"trigger_id"]) -> None: ...

global___PauseTriggerMetadata = PauseTriggerMetadata

@typing.final
class ResumeTriggerRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TRIGGER_ID_FIELD_NUMBER: builtins.int
    trigger_id: builtins.str
    """ID of the trigger to pause

    To get a trigger ID make a [TriggerService.List] request.
    """
    def __init__(
        self,
        *,
        trigger_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["trigger_id", b"trigger_id"]) -> None: ...

global___ResumeTriggerRequest = ResumeTriggerRequest

@typing.final
class ResumeTriggerMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TRIGGER_ID_FIELD_NUMBER: builtins.int
    trigger_id: builtins.str
    """ID of the trigger that is being paused."""
    def __init__(
        self,
        *,
        trigger_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["trigger_id", b"trigger_id"]) -> None: ...

global___ResumeTriggerMetadata = ResumeTriggerMetadata

@typing.final
class ListTriggerOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TRIGGER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    trigger_id: builtins.str
    """ID of the trigger to list operations for."""
    page_size: builtins.int
    """The maximum number of results per page that should be returned. If the number of available
    results is larger than `pageSize`, the service returns a [ListTriggerOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.

    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `pageToken` to the
    [ListTriggerOperationsResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.

    The expression must specify:
    1. The field name. Currently filtering can only be applied to the [Trigger.name] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    Example of a filter: `name=my-function`.
    """
    def __init__(
        self,
        *,
        trigger_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "page_size", b"page_size", "page_token", b"page_token", "trigger_id", b"trigger_id"]) -> None: ...

global___ListTriggerOperationsRequest = ListTriggerOperationsRequest

@typing.final
class ListTriggerOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListTriggerOperationsRequest.page_size], use `nextPageToken` as the value
    for the [ListTriggerOperationsRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `nextPageToken` to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified trigger."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListTriggerOperationsResponse = ListTriggerOperationsResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/greenplum/v1/host.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/greenplum/v1/host.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.mdb.greenplum.v1 import config_pb2 as yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_config__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(yandex/cloud/mdb/greenplum/v1/host.proto\x12\x1dyandex.cloud.mdb.greenplum.v1\x1a*yandex/cloud/mdb/greenplum/v1/config.proto\x1a\x1dyandex/cloud/validation.proto\"\xb3\x03\n\x04Host\x12\x1a\n\x04name\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=63\x12\x12\n\ncluster_id\x18\x02 \x01(\t\x12\x0f\n\x07zone_id\x18\x03 \x01(\t\x12\x36\n\x04type\x18\x04 \x01(\x0e\x32(.yandex.cloud.mdb.greenplum.v1.Host.Type\x12;\n\tresources\x18\x05 \x01(\x0b\x32(.yandex.cloud.mdb.greenplum.v1.Resources\x12:\n\x06health\x18\x06 \x01(\x0e\x32*.yandex.cloud.mdb.greenplum.v1.Host.Health\x12\x11\n\tsubnet_id\x18\x07 \x01(\t\x12\x18\n\x10\x61ssign_public_ip\x18\x08 \x01(\x08\"B\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06MASTER\x10\x01\x12\x0b\n\x07REPLICA\x10\x02\x12\x0b\n\x07SEGMENT\x10\x03\"H\n\x06Health\x12\x0b\n\x07UNKNOWN\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\x12\x0c\n\x08\x44\x45GRADED\x10\x03\x12\x0e\n\nUNBALANCED\x10\x04\x42p\n!yandex.cloud.api.mdb.greenplum.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplumb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.greenplum.v1.host_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!yandex.cloud.api.mdb.greenplum.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplum'
  _globals['_HOST'].fields_by_name['name']._loaded_options = None
  _globals['_HOST'].fields_by_name['name']._serialized_options = b'\350\3071\001\212\3101\004<=63'
  _globals['_HOST']._serialized_start=151
  _globals['_HOST']._serialized_end=586
  _globals['_HOST_TYPE']._serialized_start=446
  _globals['_HOST_TYPE']._serialized_end=512
  _globals['_HOST_HEALTH']._serialized_start=514
  _globals['_HOST_HEALTH']._serialized_end=586
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/kms/v1/asymmetricsignature/asymmetric_signature_key.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/kms/v1/asymmetricsignature/asymmetric_signature_key.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFyandex/cloud/kms/v1/asymmetricsignature/asymmetric_signature_key.proto\x12\'yandex.cloud.kms.v1.asymmetricsignature\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb9\x04\n\x16\x41symmetricSignatureKey\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12[\n\x06labels\x18\x06 \x03(\x0b\x32K.yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKey.LabelsEntry\x12V\n\x06status\x18\x07 \x01(\x0e\x32\x46.yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKey.Status\x12\x62\n\x13signature_algorithm\x18\x08 \x01(\x0e\x32\x45.yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureAlgorithm\x12\x1b\n\x13\x64\x65letion_protection\x18\t \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"H\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08INACTIVE\x10\x03*\xda\x03\n\x1c\x41symmetricSignatureAlgorithm\x12.\n*ASYMMETRIC_SIGNATURE_ALGORITHM_UNSPECIFIED\x10\x00\x12\x1d\n\x19RSA_2048_SIGN_PSS_SHA_256\x10\x01\x12\x1d\n\x19RSA_2048_SIGN_PSS_SHA_384\x10\x02\x12\x1d\n\x19RSA_2048_SIGN_PSS_SHA_512\x10\x03\x12\x1d\n\x19RSA_3072_SIGN_PSS_SHA_256\x10\x04\x12\x1d\n\x19RSA_3072_SIGN_PSS_SHA_384\x10\x05\x12\x1d\n\x19RSA_3072_SIGN_PSS_SHA_512\x10\x06\x12\x1d\n\x19RSA_4096_SIGN_PSS_SHA_256\x10\x07\x12\x1d\n\x19RSA_4096_SIGN_PSS_SHA_384\x10\x08\x12\x1d\n\x19RSA_4096_SIGN_PSS_SHA_512\x10\t\x12\x1b\n\x17\x45\x43\x44SA_NIST_P256_SHA_256\x10\n\x12\x1b\n\x17\x45\x43\x44SA_NIST_P384_SHA_384\x10\x0b\x12\x1b\n\x17\x45\x43\x44SA_NIST_P521_SHA_512\x10\x0c\x12\x1c\n\x18\x45\x43\x44SA_SECP256_K1_SHA_256\x10\rBj\n\x17yandex.cloud.api.kms.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/kms/v1/asymmetricsignature;kmsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.kms.v1.asymmetricsignature.asymmetric_signature_key_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.kms.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/kms/v1/asymmetricsignature;kms'
  _globals['_ASYMMETRICSIGNATUREKEY_LABELSENTRY']._loaded_options = None
  _globals['_ASYMMETRICSIGNATUREKEY_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_ASYMMETRICSIGNATUREALGORITHM']._serialized_start=721
  _globals['_ASYMMETRICSIGNATUREALGORITHM']._serialized_end=1195
  _globals['_ASYMMETRICSIGNATUREKEY']._serialized_start=149
  _globals['_ASYMMETRICSIGNATUREKEY']._serialized_end=718
  _globals['_ASYMMETRICSIGNATUREKEY_LABELSENTRY']._serialized_start=599
  _globals['_ASYMMETRICSIGNATUREKEY_LABELSENTRY']._serialized_end=644
  _globals['_ASYMMETRICSIGNATUREKEY_STATUS']._serialized_start=646
  _globals['_ASYMMETRICSIGNATUREKEY_STATUS']._serialized_end=718
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/iam/v1/user_account_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/iam/v1/user_account_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.iam.v1 import user_account_pb2 as yandex_dot_cloud_dot_iam_dot_v1_dot_user__account__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.yandex/cloud/iam/v1/user_account_service.proto\x12\x13yandex.cloud.iam.v1\x1a\x1cgoogle/api/annotations.proto\x1a&yandex/cloud/iam/v1/user_account.proto\x1a\x1dyandex/cloud/validation.proto\">\n\x15GetUserAccountRequest\x12%\n\x0fuser_account_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=502\x9a\x01\n\x12UserAccountService\x12\x83\x01\n\x03Get\x12*.yandex.cloud.iam.v1.GetUserAccountRequest\x1a .yandex.cloud.iam.v1.UserAccount\".\x82\xd3\xe4\x93\x02(\x12&/iam/v1/userAccounts/{user_account_id}BV\n\x17yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iamb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.iam.v1.user_account_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iam'
  _globals['_GETUSERACCOUNTREQUEST'].fields_by_name['user_account_id']._loaded_options = None
  _globals['_GETUSERACCOUNTREQUEST'].fields_by_name['user_account_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_USERACCOUNTSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_USERACCOUNTSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002(\022&/iam/v1/userAccounts/{user_account_id}'
  _globals['_GETUSERACCOUNTREQUEST']._serialized_start=172
  _globals['_GETUSERACCOUNTREQUEST']._serialized_end=234
  _globals['_USERACCOUNTSERVICE']._serialized_start=237
  _globals['_USERACCOUNTSERVICE']._serialized_end=391
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/dataproc/v1/job.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/dataproc/v1/job.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"yandex/cloud/dataproc/v1/job.proto\x12\x18yandex.cloud.dataproc.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd0\x05\n\x03Job\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\ncluster_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nstarted_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0b\x66inished_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x12\n\ncreated_by\x18\x0c \x01(\t\x12\x34\n\x06status\x18\x07 \x01(\x0e\x32$.yandex.cloud.dataproc.v1.Job.Status\x12?\n\rmapreduce_job\x18\x08 \x01(\x0b\x32&.yandex.cloud.dataproc.v1.MapreduceJobH\x00\x12\x37\n\tspark_job\x18\t \x01(\x0b\x32\".yandex.cloud.dataproc.v1.SparkJobH\x00\x12;\n\x0bpyspark_job\x18\n \x01(\x0b\x32$.yandex.cloud.dataproc.v1.PysparkJobH\x00\x12\x35\n\x08hive_job\x18\x0b \x01(\x0b\x32!.yandex.cloud.dataproc.v1.HiveJobH\x00\x12\x43\n\x10\x61pplication_info\x18\r \x01(\x0b\x32).yandex.cloud.dataproc.v1.ApplicationInfo\"\x80\x01\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x10\n\x0cPROVISIONING\x10\x01\x12\x0b\n\x07PENDING\x10\x02\x12\x0b\n\x07RUNNING\x10\x03\x12\t\n\x05\x45RROR\x10\x04\x12\x08\n\x04\x44ONE\x10\x05\x12\r\n\tCANCELLED\x10\x06\x12\x0e\n\nCANCELLING\x10\x07\x42\n\n\x08job_spec\"9\n\x12\x41pplicationAttempt\x12\n\n\x02id\x18\x01 \x01(\t\x12\x17\n\x0f\x61m_container_id\x18\x02 \x01(\t\"i\n\x0f\x41pplicationInfo\x12\n\n\x02id\x18\x01 \x01(\t\x12J\n\x14\x61pplication_attempts\x18\x02 \x03(\x0b\x32,.yandex.cloud.dataproc.v1.ApplicationAttempt\"\x98\x02\n\x0cMapreduceJob\x12\x0c\n\x04\x61rgs\x18\x01 \x03(\t\x12\x15\n\rjar_file_uris\x18\x02 \x03(\t\x12\x11\n\tfile_uris\x18\x03 \x03(\t\x12\x14\n\x0c\x61rchive_uris\x18\x04 \x03(\t\x12J\n\nproperties\x18\x05 \x03(\x0b\x32\x36.yandex.cloud.dataproc.v1.MapreduceJob.PropertiesEntry\x12\x1b\n\x11main_jar_file_uri\x18\x06 \x01(\tH\x00\x12\x14\n\nmain_class\x18\x07 \x01(\tH\x00\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x08\n\x06\x64river\"\xc4\x02\n\x08SparkJob\x12\x0c\n\x04\x61rgs\x18\x01 \x03(\t\x12\x15\n\rjar_file_uris\x18\x02 \x03(\t\x12\x11\n\tfile_uris\x18\x03 \x03(\t\x12\x14\n\x0c\x61rchive_uris\x18\x04 \x03(\t\x12\x46\n\nproperties\x18\x05 \x03(\x0b\x32\x32.yandex.cloud.dataproc.v1.SparkJob.PropertiesEntry\x12\x19\n\x11main_jar_file_uri\x18\x06 \x01(\t\x12\x12\n\nmain_class\x18\x07 \x01(\t\x12\x10\n\x08packages\x18\x08 \x03(\t\x12\x14\n\x0crepositories\x18\t \x03(\t\x12\x18\n\x10\x65xclude_packages\x18\n \x03(\t\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd1\x02\n\nPysparkJob\x12\x0c\n\x04\x61rgs\x18\x01 \x03(\t\x12\x15\n\rjar_file_uris\x18\x02 \x03(\t\x12\x11\n\tfile_uris\x18\x03 \x03(\t\x12\x14\n\x0c\x61rchive_uris\x18\x04 \x03(\t\x12H\n\nproperties\x18\x05 \x03(\x0b\x32\x34.yandex.cloud.dataproc.v1.PysparkJob.PropertiesEntry\x12\x1c\n\x14main_python_file_uri\x18\x06 \x01(\t\x12\x18\n\x10python_file_uris\x18\x07 \x03(\t\x12\x10\n\x08packages\x18\x08 \x03(\t\x12\x14\n\x0crepositories\x18\t \x03(\t\x12\x18\n\x10\x65xclude_packages\x18\n \x03(\t\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x1c\n\tQueryList\x12\x0f\n\x07queries\x18\x01 \x03(\t\"\xa4\x03\n\x07HiveJob\x12\x45\n\nproperties\x18\x01 \x03(\x0b\x32\x31.yandex.cloud.dataproc.v1.HiveJob.PropertiesEntry\x12\x1b\n\x13\x63ontinue_on_failure\x18\x02 \x01(\x08\x12P\n\x10script_variables\x18\x03 \x03(\x0b\x32\x36.yandex.cloud.dataproc.v1.HiveJob.ScriptVariablesEntry\x12\x15\n\rjar_file_uris\x18\x04 \x03(\t\x12\x18\n\x0equery_file_uri\x18\x05 \x01(\tH\x00\x12\x39\n\nquery_list\x18\x06 \x01(\x0b\x32#.yandex.cloud.dataproc.v1.QueryListH\x00\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x36\n\x14ScriptVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0c\n\nquery_typeBj\n\x1cyandex.cloud.api.dataproc.v1B\x03PHJZEgithub.com/yandex-cloud/go-genproto/yandex/cloud/dataproc/v1;dataprocb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.dataproc.v1.job_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034yandex.cloud.api.dataproc.v1B\003PHJZEgithub.com/yandex-cloud/go-genproto/yandex/cloud/dataproc/v1;dataproc'
  _globals['_MAPREDUCEJOB_PROPERTIESENTRY']._loaded_options = None
  _globals['_MAPREDUCEJOB_PROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_SPARKJOB_PROPERTIESENTRY']._loaded_options = None
  _globals['_SPARKJOB_PROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_PYSPARKJOB_PROPERTIESENTRY']._loaded_options = None
  _globals['_PYSPARKJOB_PROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_HIVEJOB_PROPERTIESENTRY']._loaded_options = None
  _globals['_HIVEJOB_PROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_HIVEJOB_SCRIPTVARIABLESENTRY']._loaded_options = None
  _globals['_HIVEJOB_SCRIPTVARIABLESENTRY']._serialized_options = b'8\001'
  _globals['_JOB']._serialized_start=98
  _globals['_JOB']._serialized_end=818
  _globals['_JOB_STATUS']._serialized_start=678
  _globals['_JOB_STATUS']._serialized_end=806
  _globals['_APPLICATIONATTEMPT']._serialized_start=820
  _globals['_APPLICATIONATTEMPT']._serialized_end=877
  _globals['_APPLICATIONINFO']._serialized_start=879
  _globals['_APPLICATIONINFO']._serialized_end=984
  _globals['_MAPREDUCEJOB']._serialized_start=987
  _globals['_MAPREDUCEJOB']._serialized_end=1267
  _globals['_MAPREDUCEJOB_PROPERTIESENTRY']._serialized_start=1208
  _globals['_MAPREDUCEJOB_PROPERTIESENTRY']._serialized_end=1257
  _globals['_SPARKJOB']._serialized_start=1270
  _globals['_SPARKJOB']._serialized_end=1594
  _globals['_SPARKJOB_PROPERTIESENTRY']._serialized_start=1208
  _globals['_SPARKJOB_PROPERTIESENTRY']._serialized_end=1257
  _globals['_PYSPARKJOB']._serialized_start=1597
  _globals['_PYSPARKJOB']._serialized_end=1934
  _globals['_PYSPARKJOB_PROPERTIESENTRY']._serialized_start=1208
  _globals['_PYSPARKJOB_PROPERTIESENTRY']._serialized_end=1257
  _globals['_QUERYLIST']._serialized_start=1936
  _globals['_QUERYLIST']._serialized_end=1964
  _globals['_HIVEJOB']._serialized_start=1967
  _globals['_HIVEJOB']._serialized_end=2387
  _globals['_HIVEJOB_PROPERTIESENTRY']._serialized_start=1208
  _globals['_HIVEJOB_PROPERTIESENTRY']._serialized_end=1257
  _globals['_HIVEJOB_SCRIPTVARIABLESENTRY']._serialized_start=2319
  _globals['_HIVEJOB_SCRIPTVARIABLESENTRY']._serialized_end=2373
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.logging.v1.log_group_pb2
import yandex.cloud.logging.v1.log_resource_pb2
import yandex.cloud.operation.operation_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetLogGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOG_GROUP_ID_FIELD_NUMBER: builtins.int
    log_group_id: builtins.str
    """ID of the log group to return.

    To get a log group ID make a [LogGroupService.List] request.
    """
    def __init__(
        self,
        *,
        log_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["log_group_id", b"log_group_id"]) -> None: ...

global___GetLogGroupRequest = GetLogGroupRequest

@typing.final
class GetLogGroupStatsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOG_GROUP_ID_FIELD_NUMBER: builtins.int
    log_group_id: builtins.str
    """ID of the log group to return stats for.

    To get a log group ID make a [LogGroupService.List] request.
    """
    def __init__(
        self,
        *,
        log_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["log_group_id", b"log_group_id"]) -> None: ...

global___GetLogGroupStatsRequest = GetLogGroupStatsRequest

@typing.final
class ListLogGroupsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """Folder ID of the log groups to return.

    To get a folder ID make a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than `page_size`, the service returns a [ListLogGroupsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.

    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListLogGroupsResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters log groups listed in the response.

    The expression must specify:
    1. The field name. Currently filtering can only be applied to the [LogGroup.name] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    Example of a filter: `name=my-log-group`.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListLogGroupsRequest = ListLogGroupsRequest

@typing.final
class ListLogGroupsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUPS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListLogGroupsRequest.page_size], use `next_page_token` as the value
    for the [ListLogGroupsRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.logging.v1.log_group_pb2.LogGroup]:
        """List of log groups in the specified folder."""

    def __init__(
        self,
        *,
        groups: collections.abc.Iterable[yandex.cloud.logging.v1.log_group_pb2.LogGroup] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["groups", b"groups", "next_page_token", b"next_page_token"]) -> None: ...

global___ListLogGroupsResponse = ListLogGroupsResponse

@typing.final
class CreateLogGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    RETENTION_PERIOD_FIELD_NUMBER: builtins.int
    DATA_STREAM_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create a log group in.

    To get a folder ID make a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    name: builtins.str
    """Name of the log group.
    The name must be unique within the folder.
    """
    description: builtins.str
    """Description of the log group."""
    data_stream: builtins.str
    """If specified, all log records will be written to this data stream"""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Log group labels as `key:value` pairs."""

    @property
    def retention_period(self) -> google.protobuf.duration_pb2.Duration:
        """Log group entry retention period.

        Entries will be present in group during this period.
        If specified, must be non-negative.
        Empty or zero value is treated as no limit.
        Data stream name
        """

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        retention_period: google.protobuf.duration_pb2.Duration | None = ...,
        data_stream: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["retention_period", b"retention_period"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data_stream", b"data_stream", "description", b"description", "folder_id", b"folder_id", "labels", b"labels", "name", b"name", "retention_period", b"retention_period"]) -> None: ...

global___CreateLogGroupRequest = CreateLogGroupRequest

@typing.final
class CreateLogGroupMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOG_GROUP_ID_FIELD_NUMBER: builtins.int
    log_group_id: builtins.str
    """ID of the log group being created."""
    def __init__(
        self,
        *,
        log_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["log_group_id", b"log_group_id"]) -> None: ...

global___CreateLogGroupMetadata = CreateLogGroupMetadata

@typing.final
class UpdateLogGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    LOG_GROUP_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    RETENTION_PERIOD_FIELD_NUMBER: builtins.int
    DATA_STREAM_FIELD_NUMBER: builtins.int
    log_group_id: builtins.str
    """ID of the log group to update.

    To get a log group ID make a [LogGroupService.List] request.
    """
    name: builtins.str
    """New name of the log group.
    The name must be unique within the folder.
    """
    description: builtins.str
    """New Description of the log group."""
    data_stream: builtins.str
    """Data stream name

    If specified, log records will be written to this data stream
    """
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which attributes of the function should be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """New log group labels as `key:value` pairs."""

    @property
    def retention_period(self) -> google.protobuf.duration_pb2.Duration:
        """New log group entry retention period.

        Entries will be present in group during this period.
        If specified, must be non-negative.
        Empty or zero value is treated as no limit.
        """

    def __init__(
        self,
        *,
        log_group_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        retention_period: google.protobuf.duration_pb2.Duration | None = ...,
        data_stream: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["retention_period", b"retention_period", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data_stream", b"data_stream", "description", b"description", "labels", b"labels", "log_group_id", b"log_group_id", "name", b"name", "retention_period", b"retention_period", "update_mask", b"update_mask"]) -> None: ...

global___UpdateLogGroupRequest = UpdateLogGroupRequest

@typing.final
class UpdateLogGroupMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOG_GROUP_ID_FIELD_NUMBER: builtins.int
    log_group_id: builtins.str
    """ID of the log group being updated."""
    def __init__(
        self,
        *,
        log_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["log_group_id", b"log_group_id"]) -> None: ...

global___UpdateLogGroupMetadata = UpdateLogGroupMetadata

@typing.final
class DeleteLogGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOG_GROUP_ID_FIELD_NUMBER: builtins.int
    log_group_id: builtins.str
    """ID of the log group to delete.

    To get a log group ID make a [LogGroupService.List] request.
    """
    def __init__(
        self,
        *,
        log_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["log_group_id", b"log_group_id"]) -> None: ...

global___DeleteLogGroupRequest = DeleteLogGroupRequest

@typing.final
class DeleteLogGroupMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOG_GROUP_ID_FIELD_NUMBER: builtins.int
    log_group_id: builtins.str
    """ID of the log group being deleted."""
    def __init__(
        self,
        *,
        log_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["log_group_id", b"log_group_id"]) -> None: ...

global___DeleteLogGroupMetadata = DeleteLogGroupMetadata

@typing.final
class ListResourcesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOG_GROUP_ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    log_group_id: builtins.str
    """ID of the log group to list resources for.

    To get a log group ID make a [LogGroupService.List] request.
    """
    type: builtins.str
    """Resource type to return resources for.

    If not specified, [ListResourcesResponse] will contain information about all resource types.
    """
    def __init__(
        self,
        *,
        log_group_id: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["log_group_id", b"log_group_id", "type", b"type"]) -> None: ...

global___ListResourcesRequest = ListResourcesRequest

@typing.final
class ListResourcesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCES_FIELD_NUMBER: builtins.int
    @property
    def resources(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.logging.v1.log_resource_pb2.LogGroupResource]:
        """List of resources present in log group."""

    def __init__(
        self,
        *,
        resources: collections.abc.Iterable[yandex.cloud.logging.v1.log_resource_pb2.LogGroupResource] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["resources", b"resources"]) -> None: ...

global___ListResourcesResponse = ListResourcesResponse

@typing.final
class ListOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOG_GROUP_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    log_group_id: builtins.str
    """ID of the log group to list operations for.

    To get a log group ID make a [LogGroupService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than `page_size`, the service returns a [ListOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.

    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListOperationsResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.

    The expression must specify:
    1. The field name. Currently filtering can be applied to the [operation.Operation.description], [operation.Operation.created_at], [operation.Operation.modified_at], [operation.Operation.created_by], [operation.Operation.done] fields.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    Examples of a filter: `done=false`, `created_by='John.Doe'`.
    """
    def __init__(
        self,
        *,
        log_group_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "log_group_id", b"log_group_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListOperationsRequest = ListOperationsRequest

@typing.final
class ListOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListOperationsRequest.page_size], use `next_page_token` as the value
    for the [ListOperationsRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified log group."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListOperationsResponse = ListOperationsResponse

@typing.final
class GetLogGroupStatsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOG_GROUP_ID_FIELD_NUMBER: builtins.int
    BYTES_FIELD_NUMBER: builtins.int
    RECORDS_FIELD_NUMBER: builtins.int
    log_group_id: builtins.str
    """Log group ID the stats are returned for."""
    bytes: builtins.int
    """Size of data in log group in bytes."""
    records: builtins.int
    """Amount of records in log group."""
    def __init__(
        self,
        *,
        log_group_id: builtins.str = ...,
        bytes: builtins.int = ...,
        records: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["bytes", b"bytes", "log_group_id", b"log_group_id", "records", b"records"]) -> None: ...

global___GetLogGroupStatsResponse = GetLogGroupStatsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing
import yandex.cloud.logging.v1.export_pb2
import yandex.cloud.operation.operation_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class RunExportRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_ID_FIELD_NUMBER: builtins.int
    SINK_ID_FIELD_NUMBER: builtins.int
    PARAMS_FIELD_NUMBER: builtins.int
    RESULT_FILENAME_FIELD_NUMBER: builtins.int
    SINCE_FIELD_NUMBER: builtins.int
    UNTIL_FIELD_NUMBER: builtins.int
    group_id: builtins.str
    sink_id: builtins.str
    result_filename: builtins.str
    @property
    def params(self) -> yandex.cloud.logging.v1.export_pb2.ExportParams: ...
    @property
    def since(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def until(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        group_id: builtins.str = ...,
        sink_id: builtins.str = ...,
        params: yandex.cloud.logging.v1.export_pb2.ExportParams | None = ...,
        result_filename: builtins.str = ...,
        since: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        until: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["params", b"params", "since", b"since", "until", b"until"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["group_id", b"group_id", "params", b"params", "result_filename", b"result_filename", "since", b"since", "sink_id", b"sink_id", "until", b"until"]) -> None: ...

global___RunExportRequest = RunExportRequest

@typing.final
class RunExportDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_ID_FIELD_NUMBER: builtins.int
    SINK_ID_FIELD_NUMBER: builtins.int
    PARAMS_FIELD_NUMBER: builtins.int
    RESULT_FILENAME_FIELD_NUMBER: builtins.int
    SINCE_FIELD_NUMBER: builtins.int
    UNTIL_FIELD_NUMBER: builtins.int
    group_id: builtins.str
    sink_id: builtins.str
    result_filename: builtins.str
    @property
    def params(self) -> yandex.cloud.logging.v1.export_pb2.ExportParams: ...
    @property
    def since(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def until(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        group_id: builtins.str = ...,
        sink_id: builtins.str = ...,
        params: yandex.cloud.logging.v1.export_pb2.ExportParams | None = ...,
        result_filename: builtins.str = ...,
        since: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        until: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["params", b"params", "since", b"since", "until", b"until"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["group_id", b"group_id", "params", b"params", "result_filename", b"result_filename", "since", b"since", "sink_id", b"sink_id", "until", b"until"]) -> None: ...

global___RunExportDetails = RunExportDetails

@typing.final
class RunExportMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_ID_FIELD_NUMBER: builtins.int
    SINK_ID_FIELD_NUMBER: builtins.int
    RESULT_FILENAME_FIELD_NUMBER: builtins.int
    group_id: builtins.str
    sink_id: builtins.str
    result_filename: builtins.str
    def __init__(
        self,
        *,
        group_id: builtins.str = ...,
        sink_id: builtins.str = ...,
        result_filename: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["group_id", b"group_id", "result_filename", b"result_filename", "sink_id", b"sink_id"]) -> None: ...

global___RunExportMetadata = RunExportMetadata

@typing.final
class GetExportRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXPORT_ID_FIELD_NUMBER: builtins.int
    export_id: builtins.str
    """ID of the export to return.

    To get a export ID make a [ExportService.List] request.
    """
    def __init__(
        self,
        *,
        export_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["export_id", b"export_id"]) -> None: ...

global___GetExportRequest = GetExportRequest

@typing.final
class ListExportsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """Folder ID of the exports to return.

    To get a folder ID make a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than `page_size`, the service returns a [ListExportssResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.

    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListExportsResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters exports listed in the response.

    The expression must specify:
    1. The field name. Currently filtering can only be applied to the [Export.name] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    Example of a filter: `name="my-export"`.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListExportsRequest = ListExportsRequest

@typing.final
class ListExportsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXPORTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListExportsRequest.page_size], use `next_page_token` as the value
    for the [ListExportsRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def exports(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.logging.v1.export_pb2.Export]:
        """List of exports in the specified folder."""

    def __init__(
        self,
        *,
        exports: collections.abc.Iterable[yandex.cloud.logging.v1.export_pb2.Export] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["exports", b"exports", "next_page_token", b"next_page_token"]) -> None: ...

global___ListExportsResponse = ListExportsResponse

@typing.final
class CreateExportRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    GROUP_ID_FIELD_NUMBER: builtins.int
    SINK_ID_FIELD_NUMBER: builtins.int
    PARAMS_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create a export in.

    To get a folder ID make a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    name: builtins.str
    """Name of the export.
    The name must be unique within the folder.
    """
    description: builtins.str
    """Description of the export."""
    group_id: builtins.str
    """Logging Group ID logs exported from"""
    sink_id: builtins.str
    """Logging Sink ID logs exported to"""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Export labels as `key:value` pairs."""

    @property
    def params(self) -> yandex.cloud.logging.v1.export_pb2.ExportParams:
        """Parameters for logs filtration"""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        group_id: builtins.str = ...,
        sink_id: builtins.str = ...,
        params: yandex.cloud.logging.v1.export_pb2.ExportParams | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["params", b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "folder_id", b"folder_id", "group_id", b"group_id", "labels", b"labels", "name", b"name", "params", b"params", "sink_id", b"sink_id"]) -> None: ...

global___CreateExportRequest = CreateExportRequest

@typing.final
class CreateExportMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXPORT_ID_FIELD_NUMBER: builtins.int
    export_id: builtins.str
    """ID of the export being created."""
    def __init__(
        self,
        *,
        export_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["export_id", b"export_id"]) -> None: ...

global___CreateExportMetadata = CreateExportMetadata

@typing.final
class UpdateExportRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    EXPORT_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    GROUP_ID_FIELD_NUMBER: builtins.int
    SINK_ID_FIELD_NUMBER: builtins.int
    PARAMS_FIELD_NUMBER: builtins.int
    export_id: builtins.str
    """ID of the export to update.

    To get a export ID make a [ExportService.List] request.
    """
    name: builtins.str
    """New name of the export.
    The name must be unique within the folder.
    """
    description: builtins.str
    """New Description of the export."""
    group_id: builtins.str
    """New logging Group ID logs exported from"""
    sink_id: builtins.str
    """New logging Sink ID logs exported to"""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which attributes of the function should be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """New export labels as `key:value` pairs."""

    @property
    def params(self) -> yandex.cloud.logging.v1.export_pb2.ExportParams:
        """New parameters for logs filtration"""

    def __init__(
        self,
        *,
        export_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        group_id: builtins.str = ...,
        sink_id: builtins.str = ...,
        params: yandex.cloud.logging.v1.export_pb2.ExportParams | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["params", b"params", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "export_id", b"export_id", "group_id", b"group_id", "labels", b"labels", "name", b"name", "params", b"params", "sink_id", b"sink_id", "update_mask", b"update_mask"]) -> None: ...

global___UpdateExportRequest = UpdateExportRequest

@typing.final
class UpdateExportMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXPORT_ID_FIELD_NUMBER: builtins.int
    export_id: builtins.str
    """ID of the export being updated."""
    def __init__(
        self,
        *,
        export_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["export_id", b"export_id"]) -> None: ...

global___UpdateExportMetadata = UpdateExportMetadata

@typing.final
class DeleteExportRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXPORT_ID_FIELD_NUMBER: builtins.int
    export_id: builtins.str
    """ID of the export to delete.

    To get a export ID make a [ExportService.List] request.
    """
    def __init__(
        self,
        *,
        export_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["export_id", b"export_id"]) -> None: ...

global___DeleteExportRequest = DeleteExportRequest

@typing.final
class DeleteExportMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXPORT_ID_FIELD_NUMBER: builtins.int
    export_id: builtins.str
    """ID of the export being deleted."""
    def __init__(
        self,
        *,
        export_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["export_id", b"export_id"]) -> None: ...

global___DeleteExportMetadata = DeleteExportMetadata

@typing.final
class ListExportOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXPORT_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    export_id: builtins.str
    """ID of the export to list operations for.

    To get a export ID make a [ExportService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than `page_size`, the service returns a [ListExportOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.

    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListExportOperationsResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.

    The expression must specify:
    1. The field name. Currently filtering can be applied to the [operation.Operation.description], [operation.Operation.created_at], [operation.Operation.modified_at], [operation.Operation.created_by], [operation.Operation.done] fields.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    Examples of a filter: `done=false`, `created_by='John.Doe'`.
    """
    def __init__(
        self,
        *,
        export_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["export_id", b"export_id", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListExportOperationsRequest = ListExportOperationsRequest

@typing.final
class ListExportOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListOExportperationsRequest.page_size], use `next_page_token` as the value
    for the [ListExportOperationsRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified export."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListExportOperationsResponse = ListExportOperationsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.compute.v1.disk_pb2
import yandex.cloud.compute.v1.hardware_generation_pb2
import yandex.cloud.compute.v1.snapshot_schedule_pb2
import yandex.cloud.operation.operation_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetDiskRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISK_ID_FIELD_NUMBER: builtins.int
    disk_id: builtins.str
    """ID of the Disk resource to return.
    To get the disk ID use a [DiskService.List] request.
    """
    def __init__(
        self,
        *,
        disk_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["disk_id", b"disk_id"]) -> None: ...

global___GetDiskRequest = GetDiskRequest

@typing.final
class ListDisksRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list disks in.
    To get the folder ID use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListDisksResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListDisksResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    The expression consists of one or more conditions united by `AND` operator: `<condition1> [AND <condition2> [<...> AND <conditionN>]]`.

    Each condition has the form `<field> <operator> <value>`, where:
    1. `<field>` is the field name. Currently you can use filtering only on the limited number of fields.
    2. `<operator>` is a logical operator, one of `=`, `!=`, `IN`, `NOT IN`.
    3. `<value>` represents a value.
    String values should be written in double (`"`) or single (`'`) quotes. C-style escape sequences are supported (`\\"` turns to `"`, `\\'` to `'`, `\\\\` to backslash).
    """
    order_by: builtins.str
    """By which column the listing should be ordered and in which direction,
    format is "createdAt desc". "id asc" if omitted.
    The default sorting order is ascending
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
        order_by: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "order_by", b"order_by", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListDisksRequest = ListDisksRequest

@typing.final
class ListDisksResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISKS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListDisksRequest.page_size], use
    the [next_page_token] as the value
    for the [ListDisksRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def disks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.compute.v1.disk_pb2.Disk]:
        """List of Disk resources."""

    def __init__(
        self,
        *,
        disks: collections.abc.Iterable[yandex.cloud.compute.v1.disk_pb2.Disk] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["disks", b"disks", "next_page_token", b"next_page_token"]) -> None: ...

global___ListDisksResponse = ListDisksResponse

@typing.final
class CreateDiskRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    TYPE_ID_FIELD_NUMBER: builtins.int
    ZONE_ID_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    IMAGE_ID_FIELD_NUMBER: builtins.int
    SNAPSHOT_ID_FIELD_NUMBER: builtins.int
    BLOCK_SIZE_FIELD_NUMBER: builtins.int
    DISK_PLACEMENT_POLICY_FIELD_NUMBER: builtins.int
    SNAPSHOT_SCHEDULE_IDS_FIELD_NUMBER: builtins.int
    HARDWARE_GENERATION_FIELD_NUMBER: builtins.int
    KMS_KEY_ID_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create a disk in.
    To get the folder ID use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    name: builtins.str
    """Name of the disk."""
    description: builtins.str
    """Description of the disk."""
    type_id: builtins.str
    """ID of the disk type.
    To get a list of available disk types use the [yandex.cloud.compute.v1.DiskTypeService.List] request.
    """
    zone_id: builtins.str
    """ID of the availability zone where the disk resides.
    To get a list of available zones use the [yandex.cloud.compute.v1.ZoneService.List] request.
    """
    size: builtins.int
    """Size of the disk, specified in bytes.
    If the disk was created from a image, this value should be more than the
    [yandex.cloud.compute.v1.Image.min_disk_size] value.
    """
    image_id: builtins.str
    """ID of the image to create the disk from."""
    snapshot_id: builtins.str
    """ID of the snapshot to restore the disk from."""
    block_size: builtins.int
    """Block size used for disk, specified in bytes. The default is 4096."""
    kms_key_id: builtins.str
    """ID of KMS key for disk encryption."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs."""

    @property
    def disk_placement_policy(self) -> yandex.cloud.compute.v1.disk_pb2.DiskPlacementPolicy:
        """Placement policy configuration."""

    @property
    def snapshot_schedule_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of IDs of the snapshot schedules to attach the disk to."""

    @property
    def hardware_generation(self) -> yandex.cloud.compute.v1.hardware_generation_pb2.HardwareGeneration:
        """Specify the overrides to hardware_generation of a source disk, image or snapshot,
        or to the default values if the source does not define it.
        """

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        type_id: builtins.str = ...,
        zone_id: builtins.str = ...,
        size: builtins.int = ...,
        image_id: builtins.str = ...,
        snapshot_id: builtins.str = ...,
        block_size: builtins.int = ...,
        disk_placement_policy: yandex.cloud.compute.v1.disk_pb2.DiskPlacementPolicy | None = ...,
        snapshot_schedule_ids: collections.abc.Iterable[builtins.str] | None = ...,
        hardware_generation: yandex.cloud.compute.v1.hardware_generation_pb2.HardwareGeneration | None = ...,
        kms_key_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["disk_placement_policy", b"disk_placement_policy", "hardware_generation", b"hardware_generation", "image_id", b"image_id", "snapshot_id", b"snapshot_id", "source", b"source"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["block_size", b"block_size", "description", b"description", "disk_placement_policy", b"disk_placement_policy", "folder_id", b"folder_id", "hardware_generation", b"hardware_generation", "image_id", b"image_id", "kms_key_id", b"kms_key_id", "labels", b"labels", "name", b"name", "size", b"size", "snapshot_id", b"snapshot_id", "snapshot_schedule_ids", b"snapshot_schedule_ids", "source", b"source", "type_id", b"type_id", "zone_id", b"zone_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["source", b"source"]) -> typing.Literal["image_id", "snapshot_id"] | None: ...

global___CreateDiskRequest = CreateDiskRequest

@typing.final
class CreateDiskMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISK_ID_FIELD_NUMBER: builtins.int
    disk_id: builtins.str
    """ID of the disk that is being created."""
    def __init__(
        self,
        *,
        disk_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["disk_id", b"disk_id"]) -> None: ...

global___CreateDiskMetadata = CreateDiskMetadata

@typing.final
class UpdateDiskRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    DISK_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    DISK_PLACEMENT_POLICY_FIELD_NUMBER: builtins.int
    disk_id: builtins.str
    """ID of the Disk resource to update.
    To get the disk ID use a [DiskService.List] request.
    """
    name: builtins.str
    """Name of the disk."""
    description: builtins.str
    """Description of the disk."""
    size: builtins.int
    """Size of the disk, specified in bytes."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the Disk resource are going to be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs.

        Existing set of `labels` is completely replaced by the provided set.
        """

    @property
    def disk_placement_policy(self) -> yandex.cloud.compute.v1.disk_pb2.DiskPlacementPolicy:
        """Placement policy configuration."""

    def __init__(
        self,
        *,
        disk_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        size: builtins.int = ...,
        disk_placement_policy: yandex.cloud.compute.v1.disk_pb2.DiskPlacementPolicy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["disk_placement_policy", b"disk_placement_policy", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "disk_id", b"disk_id", "disk_placement_policy", b"disk_placement_policy", "labels", b"labels", "name", b"name", "size", b"size", "update_mask", b"update_mask"]) -> None: ...

global___UpdateDiskRequest = UpdateDiskRequest

@typing.final
class UpdateDiskMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISK_ID_FIELD_NUMBER: builtins.int
    disk_id: builtins.str
    """ID of the Disk resource that is being updated."""
    def __init__(
        self,
        *,
        disk_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["disk_id", b"disk_id"]) -> None: ...

global___UpdateDiskMetadata = UpdateDiskMetadata

@typing.final
class DeleteDiskRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISK_ID_FIELD_NUMBER: builtins.int
    disk_id: builtins.str
    """ID of the disk to delete.
    To get the disk ID use a [DiskService.List] request.
    """
    def __init__(
        self,
        *,
        disk_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["disk_id", b"disk_id"]) -> None: ...

global___DeleteDiskRequest = DeleteDiskRequest

@typing.final
class DeleteDiskMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISK_ID_FIELD_NUMBER: builtins.int
    disk_id: builtins.str
    """ID of the disk that is being deleted."""
    def __init__(
        self,
        *,
        disk_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["disk_id", b"disk_id"]) -> None: ...

global___DeleteDiskMetadata = DeleteDiskMetadata

@typing.final
class ListDiskOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISK_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    disk_id: builtins.str
    """ID of the Disk resource to list operations for."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size], the service returns a [ListDiskOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListDiskOperationsResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        disk_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["disk_id", b"disk_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListDiskOperationsRequest = ListDiskOperationsRequest

@typing.final
class ListDiskOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListDiskOperationsRequest.page_size], use the [next_page_token] as the value
    for the [ListDiskOperationsRequest.page_token] query parameter in the next list request.
    Each subsequent list request will have its own [next_page_token] to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified disk."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListDiskOperationsResponse = ListDiskOperationsResponse

@typing.final
class MoveDiskRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISK_ID_FIELD_NUMBER: builtins.int
    DESTINATION_FOLDER_ID_FIELD_NUMBER: builtins.int
    disk_id: builtins.str
    """ID of the disk to move.

    To get the disk ID, make a [DiskService.List] request.
    """
    destination_folder_id: builtins.str
    """ID of the folder to move the disk to.

    To get the folder ID, make a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    def __init__(
        self,
        *,
        disk_id: builtins.str = ...,
        destination_folder_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["destination_folder_id", b"destination_folder_id", "disk_id", b"disk_id"]) -> None: ...

global___MoveDiskRequest = MoveDiskRequest

@typing.final
class MoveDiskMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISK_ID_FIELD_NUMBER: builtins.int
    SOURCE_FOLDER_ID_FIELD_NUMBER: builtins.int
    DESTINATION_FOLDER_ID_FIELD_NUMBER: builtins.int
    disk_id: builtins.str
    """ID of the disk that is being moved."""
    source_folder_id: builtins.str
    """ID of the folder that the disk is being moved from."""
    destination_folder_id: builtins.str
    """ID of the folder that the disk is being moved to."""
    def __init__(
        self,
        *,
        disk_id: builtins.str = ...,
        source_folder_id: builtins.str = ...,
        destination_folder_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["destination_folder_id", b"destination_folder_id", "disk_id", b"disk_id", "source_folder_id", b"source_folder_id"]) -> None: ...

global___MoveDiskMetadata = MoveDiskMetadata

@typing.final
class RelocateDiskRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISK_ID_FIELD_NUMBER: builtins.int
    DESTINATION_ZONE_ID_FIELD_NUMBER: builtins.int
    DISK_PLACEMENT_POLICY_FIELD_NUMBER: builtins.int
    disk_id: builtins.str
    """ID of the disk to move.

    To get the disk ID, make a [DiskService.List] request.
    """
    destination_zone_id: builtins.str
    """ID of the availability zone to move the disk to.

    To get the zone ID, make a [ZoneService.List] request.
    """
    @property
    def disk_placement_policy(self) -> yandex.cloud.compute.v1.disk_pb2.DiskPlacementPolicy:
        """Placement policy configuration in target zone. Must be specified if disk has placement policy."""

    def __init__(
        self,
        *,
        disk_id: builtins.str = ...,
        destination_zone_id: builtins.str = ...,
        disk_placement_policy: yandex.cloud.compute.v1.disk_pb2.DiskPlacementPolicy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["disk_placement_policy", b"disk_placement_policy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["destination_zone_id", b"destination_zone_id", "disk_id", b"disk_id", "disk_placement_policy", b"disk_placement_policy"]) -> None: ...

global___RelocateDiskRequest = RelocateDiskRequest

@typing.final
class RelocateDiskMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISK_ID_FIELD_NUMBER: builtins.int
    SOURCE_ZONE_ID_FIELD_NUMBER: builtins.int
    DESTINATION_ZONE_ID_FIELD_NUMBER: builtins.int
    disk_id: builtins.str
    """ID of the disk that is being moved."""
    source_zone_id: builtins.str
    """ID of the availability zone that the disk is being moved from."""
    destination_zone_id: builtins.str
    """ID of the availability zone that the disk is being moved to."""
    def __init__(
        self,
        *,
        disk_id: builtins.str = ...,
        source_zone_id: builtins.str = ...,
        destination_zone_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["destination_zone_id", b"destination_zone_id", "disk_id", b"disk_id", "source_zone_id", b"source_zone_id"]) -> None: ...

global___RelocateDiskMetadata = RelocateDiskMetadata

@typing.final
class ListDiskSnapshotSchedulesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISK_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    disk_id: builtins.str
    """ID of the disk to list snapshot schedules for."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than `page_size`, the service returns a [ListDiskSnapshotSchedulesResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.

    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListDiskSnapshotSchedulesResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        disk_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["disk_id", b"disk_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListDiskSnapshotSchedulesRequest = ListDiskSnapshotSchedulesRequest

@typing.final
class ListDiskSnapshotSchedulesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SNAPSHOT_SCHEDULES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListDiskSnapshotSchedulesRequest.page_size], use `next_page_token` as the value
    for the [ListDiskSnapshotSchedulesRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def snapshot_schedules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.compute.v1.snapshot_schedule_pb2.SnapshotSchedule]:
        """List of snapshot schedules the specified disk is attached to."""

    def __init__(
        self,
        *,
        snapshot_schedules: collections.abc.Iterable[yandex.cloud.compute.v1.snapshot_schedule_pb2.SnapshotSchedule] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "snapshot_schedules", b"snapshot_schedules"]) -> None: ...

global___ListDiskSnapshotSchedulesResponse = ListDiskSnapshotSchedulesResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.cloudregistry.v1.artifact_pb2
import yandex.cloud.cloudregistry.v1.ip_permission_pb2
import yandex.cloud.cloudregistry.v1.registry_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetRegistryRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGISTRY_ID_FIELD_NUMBER: builtins.int
    registry_id: builtins.str
    """ID of the Registry resource to return.

    To get the registry ID use a [RegistryService.List] request.
    """
    def __init__(
        self,
        *,
        registry_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["registry_id", b"registry_id"]) -> None: ...

global___GetRegistryRequest = GetRegistryRequest

@typing.final
class ListRegistriesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list registries in.

    To get the folder ID use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListRegistriesResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 10.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListRegistriesResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListRegistriesRequest = ListRegistriesRequest

@typing.final
class ListRegistriesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGISTRIES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListRegistriesRequest.page_size], use
    the [next_page_token] as the value
    for the [ListRegistriesRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def registries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.cloudregistry.v1.registry_pb2.Registry]:
        """List of Registry resources."""

    def __init__(
        self,
        *,
        registries: collections.abc.Iterable[yandex.cloud.cloudregistry.v1.registry_pb2.Registry] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "registries", b"registries"]) -> None: ...

global___ListRegistriesResponse = ListRegistriesResponse

@typing.final
class CreateRegistryRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing.final
    class PropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    PROPERTIES_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create a registry in.

    To get the folder ID, use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    name: builtins.str
    """Name of the registry.

    There may be only one registry per folder.
    """
    kind: yandex.cloud.cloudregistry.v1.registry_pb2.Registry.Kind.ValueType
    """Kind of the registry."""
    type: yandex.cloud.cloudregistry.v1.registry_pb2.Registry.Type.ValueType
    """Type of the registry."""
    description: builtins.str
    """Description of the registry. 0-1024 characters long."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs."""

    @property
    def properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Property names and values."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        kind: yandex.cloud.cloudregistry.v1.registry_pb2.Registry.Kind.ValueType = ...,
        type: yandex.cloud.cloudregistry.v1.registry_pb2.Registry.Type.ValueType = ...,
        description: builtins.str = ...,
        properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "folder_id", b"folder_id", "kind", b"kind", "labels", b"labels", "name", b"name", "properties", b"properties", "type", b"type"]) -> None: ...

global___CreateRegistryRequest = CreateRegistryRequest

@typing.final
class CreateRegistryMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGISTRY_ID_FIELD_NUMBER: builtins.int
    registry_id: builtins.str
    """ID of the registry that is being created."""
    def __init__(
        self,
        *,
        registry_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["registry_id", b"registry_id"]) -> None: ...

global___CreateRegistryMetadata = CreateRegistryMetadata

@typing.final
class UpdateRegistryRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing.final
    class PropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    REGISTRY_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    PROPERTIES_FIELD_NUMBER: builtins.int
    registry_id: builtins.str
    """ID of the Registry resource to update.

    To get the registry ID use a [RegistryService.List] request.
    """
    name: builtins.str
    """Name of the registry.

    There may be only one registry per folder.
    """
    description: builtins.str
    """Description of the registry. 0-1024 characters long."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the Registry resource are going to be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs.

        Existing set of `labels` is completely replaced by the provided set.
        """

    @property
    def properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Property names and values."""

    def __init__(
        self,
        *,
        registry_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        description: builtins.str = ...,
        properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "labels", b"labels", "name", b"name", "properties", b"properties", "registry_id", b"registry_id", "update_mask", b"update_mask"]) -> None: ...

global___UpdateRegistryRequest = UpdateRegistryRequest

@typing.final
class UpdateRegistryMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGISTRY_ID_FIELD_NUMBER: builtins.int
    registry_id: builtins.str
    """ID of the Registry resource that is being updated."""
    def __init__(
        self,
        *,
        registry_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["registry_id", b"registry_id"]) -> None: ...

global___UpdateRegistryMetadata = UpdateRegistryMetadata

@typing.final
class DeleteRegistryRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGISTRY_ID_FIELD_NUMBER: builtins.int
    registry_id: builtins.str
    """ID of the registry to delete."""
    def __init__(
        self,
        *,
        registry_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["registry_id", b"registry_id"]) -> None: ...

global___DeleteRegistryRequest = DeleteRegistryRequest

@typing.final
class DeleteRegistryMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGISTRY_ID_FIELD_NUMBER: builtins.int
    registry_id: builtins.str
    """ID of the registry that is being deleted."""
    def __init__(
        self,
        *,
        registry_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["registry_id", b"registry_id"]) -> None: ...

global___DeleteRegistryMetadata = DeleteRegistryMetadata

@typing.final
class SetIpPermissionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGISTRY_ID_FIELD_NUMBER: builtins.int
    IP_PERMISSIONS_FIELD_NUMBER: builtins.int
    registry_id: builtins.str
    """ID of the registry for which ip permissions are being set."""
    @property
    def ip_permissions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.cloudregistry.v1.ip_permission_pb2.IpPermission]:
        """IP permission to be set."""

    def __init__(
        self,
        *,
        registry_id: builtins.str = ...,
        ip_permissions: collections.abc.Iterable[yandex.cloud.cloudregistry.v1.ip_permission_pb2.IpPermission] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["ip_permissions", b"ip_permissions", "registry_id", b"registry_id"]) -> None: ...

global___SetIpPermissionsRequest = SetIpPermissionsRequest

@typing.final
class UpdateIpPermissionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGISTRY_ID_FIELD_NUMBER: builtins.int
    IP_PERMISSION_DELTAS_FIELD_NUMBER: builtins.int
    registry_id: builtins.str
    """ID of the registry for which ip permissions are being updated."""
    @property
    def ip_permission_deltas(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.cloudregistry.v1.ip_permission_pb2.IpPermissionDelta]:
        """Updates to IP permissions."""

    def __init__(
        self,
        *,
        registry_id: builtins.str = ...,
        ip_permission_deltas: collections.abc.Iterable[yandex.cloud.cloudregistry.v1.ip_permission_pb2.IpPermissionDelta] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["ip_permission_deltas", b"ip_permission_deltas", "registry_id", b"registry_id"]) -> None: ...

global___UpdateIpPermissionsRequest = UpdateIpPermissionsRequest

@typing.final
class ListIpPermissionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGISTRY_ID_FIELD_NUMBER: builtins.int
    registry_id: builtins.str
    """ID of the Registry to return ip permission list."""
    def __init__(
        self,
        *,
        registry_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["registry_id", b"registry_id"]) -> None: ...

global___ListIpPermissionsRequest = ListIpPermissionsRequest

@typing.final
class ListIpPermissionsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PERMISSIONS_FIELD_NUMBER: builtins.int
    @property
    def permissions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.cloudregistry.v1.ip_permission_pb2.IpPermission]:
        """List of ip permissions for registry"""

    def __init__(
        self,
        *,
        permissions: collections.abc.Iterable[yandex.cloud.cloudregistry.v1.ip_permission_pb2.IpPermission] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["permissions", b"permissions"]) -> None: ...

global___ListIpPermissionsResponse = ListIpPermissionsResponse

@typing.final
class SetIpPermissionsMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGISTRY_ID_FIELD_NUMBER: builtins.int
    registry_id: builtins.str
    """ID of the registry that ip permission is being set."""
    def __init__(
        self,
        *,
        registry_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["registry_id", b"registry_id"]) -> None: ...

global___SetIpPermissionsMetadata = SetIpPermissionsMetadata

@typing.final
class UpdateIpPermissionsMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGISTRY_ID_FIELD_NUMBER: builtins.int
    registry_id: builtins.str
    """ID of the registry that ip permission is being updated."""
    def __init__(
        self,
        *,
        registry_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["registry_id", b"registry_id"]) -> None: ...

global___UpdateIpPermissionsMetadata = UpdateIpPermissionsMetadata

@typing.final
class ListArtifactsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGISTRY_ID_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    registry_id: builtins.str
    """ID of the registry artifact to list repositories in.

    To get the registry ID use a [ArtifactService.List] request.
    """
    path: builtins.str
    """The path to a specific node where the registry artifact is located."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListRepositoriesResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 10.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListArtifactsResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        registry_id: builtins.str = ...,
        path: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["page_size", b"page_size", "page_token", b"page_token", "path", b"path", "registry_id", b"registry_id"]) -> None: ...

global___ListArtifactsRequest = ListArtifactsRequest

@typing.final
class ListArtifactsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ARTIFACTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListRegistriesRequest.page_size], use
    the [next_page_token] as the value
    for the [ListArtifactsRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def artifacts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.cloudregistry.v1.artifact_pb2.Artifact]:
        """List of Registry artifact resources."""

    def __init__(
        self,
        *,
        artifacts: collections.abc.Iterable[yandex.cloud.cloudregistry.v1.artifact_pb2.Artifact] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["artifacts", b"artifacts", "next_page_token", b"next_page_token"]) -> None: ...

global___ListArtifactsResponse = ListArtifactsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.empty_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ObjectTransferStage:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ObjectTransferStageEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ObjectTransferStage.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    OBJECT_TRANSFER_STAGE_UNSPECIFIED: _ObjectTransferStage.ValueType  # 0
    BEFORE_DATA: _ObjectTransferStage.ValueType  # 1
    """Before data transfer"""
    AFTER_DATA: _ObjectTransferStage.ValueType  # 2
    """After data transfer"""
    NEVER: _ObjectTransferStage.ValueType  # 3
    """Don't copy"""

class ObjectTransferStage(_ObjectTransferStage, metaclass=_ObjectTransferStageEnumTypeWrapper): ...

OBJECT_TRANSFER_STAGE_UNSPECIFIED: ObjectTransferStage.ValueType  # 0
BEFORE_DATA: ObjectTransferStage.ValueType  # 1
"""Before data transfer"""
AFTER_DATA: ObjectTransferStage.ValueType  # 2
"""After data transfer"""
NEVER: ObjectTransferStage.ValueType  # 3
"""Don't copy"""
global___ObjectTransferStage = ObjectTransferStage

class _CleanupPolicy:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CleanupPolicyEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CleanupPolicy.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CLEANUP_POLICY_UNSPECIFIED: _CleanupPolicy.ValueType  # 0
    DISABLED: _CleanupPolicy.ValueType  # 1
    """Don't cleanup"""
    DROP: _CleanupPolicy.ValueType  # 2
    """Drop"""
    TRUNCATE: _CleanupPolicy.ValueType  # 3
    """Truncate"""

class CleanupPolicy(_CleanupPolicy, metaclass=_CleanupPolicyEnumTypeWrapper): ...

CLEANUP_POLICY_UNSPECIFIED: CleanupPolicy.ValueType  # 0
DISABLED: CleanupPolicy.ValueType  # 1
"""Don't cleanup"""
DROP: CleanupPolicy.ValueType  # 2
"""Drop"""
TRUNCATE: CleanupPolicy.ValueType  # 3
"""Truncate"""
global___CleanupPolicy = CleanupPolicy

class _ColumnType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ColumnTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ColumnType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    COLUMN_TYPE_UNSPECIFIED: _ColumnType.ValueType  # 0
    INT32: _ColumnType.ValueType  # 1
    INT16: _ColumnType.ValueType  # 2
    INT8: _ColumnType.ValueType  # 3
    UINT64: _ColumnType.ValueType  # 4
    UINT32: _ColumnType.ValueType  # 5
    UINT16: _ColumnType.ValueType  # 6
    UINT8: _ColumnType.ValueType  # 7
    DOUBLE: _ColumnType.ValueType  # 8
    BOOLEAN: _ColumnType.ValueType  # 9
    STRING: _ColumnType.ValueType  # 10
    UTF8: _ColumnType.ValueType  # 11
    ANY: _ColumnType.ValueType  # 12
    DATETIME: _ColumnType.ValueType  # 13
    INT64: _ColumnType.ValueType  # 14

class ColumnType(_ColumnType, metaclass=_ColumnTypeEnumTypeWrapper): ...

COLUMN_TYPE_UNSPECIFIED: ColumnType.ValueType  # 0
INT32: ColumnType.ValueType  # 1
INT16: ColumnType.ValueType  # 2
INT8: ColumnType.ValueType  # 3
UINT64: ColumnType.ValueType  # 4
UINT32: ColumnType.ValueType  # 5
UINT16: ColumnType.ValueType  # 6
UINT8: ColumnType.ValueType  # 7
DOUBLE: ColumnType.ValueType  # 8
BOOLEAN: ColumnType.ValueType  # 9
STRING: ColumnType.ValueType  # 10
UTF8: ColumnType.ValueType  # 11
ANY: ColumnType.ValueType  # 12
DATETIME: ColumnType.ValueType  # 13
INT64: ColumnType.ValueType  # 14
global___ColumnType = ColumnType

@typing.final
class AltName(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FROM_NAME_FIELD_NUMBER: builtins.int
    TO_NAME_FIELD_NUMBER: builtins.int
    from_name: builtins.str
    """Source table name"""
    to_name: builtins.str
    """Target table name"""
    def __init__(
        self,
        *,
        from_name: builtins.str = ...,
        to_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["from_name", b"from_name", "to_name", b"to_name"]) -> None: ...

global___AltName = AltName

@typing.final
class Secret(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RAW_FIELD_NUMBER: builtins.int
    raw: builtins.str
    """Raw secret value"""
    def __init__(
        self,
        *,
        raw: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["raw", b"raw", "value", b"value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["raw", b"raw", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["value", b"value"]) -> typing.Literal["raw"] | None: ...

global___Secret = Secret

@typing.final
class ColSchema(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    REQUIRED_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    name: builtins.str
    type: global___ColumnType.ValueType
    key: builtins.bool
    required: builtins.bool
    path: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        type: global___ColumnType.ValueType = ...,
        key: builtins.bool = ...,
        required: builtins.bool = ...,
        path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["key", b"key", "name", b"name", "path", b"path", "required", b"required", "type", b"type"]) -> None: ...

global___ColSchema = ColSchema

@typing.final
class TLSMode(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISABLED_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    @property
    def disabled(self) -> google.protobuf.empty_pb2.Empty: ...
    @property
    def enabled(self) -> global___TLSConfig: ...
    def __init__(
        self,
        *,
        disabled: google.protobuf.empty_pb2.Empty | None = ...,
        enabled: global___TLSConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["disabled", b"disabled", "enabled", b"enabled", "tls_mode", b"tls_mode"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["disabled", b"disabled", "enabled", b"enabled", "tls_mode", b"tls_mode"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["tls_mode", b"tls_mode"]) -> typing.Literal["disabled", "enabled"] | None: ...

global___TLSMode = TLSMode

@typing.final
class TLSConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CA_CERTIFICATE_FIELD_NUMBER: builtins.int
    ca_certificate: builtins.str
    """CA certificate

    X.509 certificate of the certificate authority which issued the server's
    certificate, in PEM format. When CA certificate is specified TLS is used to
    connect to the server.
    """
    def __init__(
        self,
        *,
        ca_certificate: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["ca_certificate", b"ca_certificate"]) -> None: ...

global___TLSConfig = TLSConfig

@typing.final
class ColumnValue(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STRING_VALUE_FIELD_NUMBER: builtins.int
    string_value: builtins.str
    def __init__(
        self,
        *,
        string_value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["string_value", b"string_value", "value", b"value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["string_value", b"string_value", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["value", b"value"]) -> typing.Literal["string_value"] | None: ...

global___ColumnValue = ColumnValue

@typing.final
class DataTransformationOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLOUD_FUNCTION_FIELD_NUMBER: builtins.int
    NUMBER_OF_RETRIES_FIELD_NUMBER: builtins.int
    BUFFER_SIZE_FIELD_NUMBER: builtins.int
    BUFFER_FLUSH_INTERVAL_FIELD_NUMBER: builtins.int
    INVOCATION_TIMEOUT_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    cloud_function: builtins.str
    """Cloud function"""
    number_of_retries: builtins.int
    """Number of retries"""
    buffer_size: builtins.str
    """Buffer size for function"""
    buffer_flush_interval: builtins.str
    """Flush interval"""
    invocation_timeout: builtins.str
    """Invocation timeout"""
    service_account_id: builtins.str
    """Service account"""
    def __init__(
        self,
        *,
        cloud_function: builtins.str = ...,
        number_of_retries: builtins.int = ...,
        buffer_size: builtins.str = ...,
        buffer_flush_interval: builtins.str = ...,
        invocation_timeout: builtins.str = ...,
        service_account_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["buffer_flush_interval", b"buffer_flush_interval", "buffer_size", b"buffer_size", "cloud_function", b"cloud_function", "invocation_timeout", b"invocation_timeout", "number_of_retries", b"number_of_retries", "service_account_id", b"service_account_id"]) -> None: ...

global___DataTransformationOptions = DataTransformationOptions

@typing.final
class FieldList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIELDS_FIELD_NUMBER: builtins.int
    @property
    def fields(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ColSchema]:
        """Column schema"""

    def __init__(
        self,
        *,
        fields: collections.abc.Iterable[global___ColSchema] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["fields", b"fields"]) -> None: ...

global___FieldList = FieldList

@typing.final
class DataSchema(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JSON_FIELDS_FIELD_NUMBER: builtins.int
    FIELDS_FIELD_NUMBER: builtins.int
    json_fields: builtins.str
    @property
    def fields(self) -> global___FieldList: ...
    def __init__(
        self,
        *,
        json_fields: builtins.str = ...,
        fields: global___FieldList | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["fields", b"fields", "json_fields", b"json_fields", "schema", b"schema"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["fields", b"fields", "json_fields", b"json_fields", "schema", b"schema"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["schema", b"schema"]) -> typing.Literal["json_fields", "fields"] | None: ...

global___DataSchema = DataSchema

@typing.final
class NoAuth(google.protobuf.message.Message):
    """No authentication"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___NoAuth = NoAuth

@typing.final
class ConnectionManagerConnection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTION_ID_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    connection_id: builtins.str
    subnet_id: builtins.str
    """Network interface for endpoint. If none will assume public ipv4"""
    def __init__(
        self,
        *,
        connection_id: builtins.str = ...,
        subnet_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["connection_id", b"connection_id", "subnet_id", b"subnet_id"]) -> None: ...

global___ConnectionManagerConnection = ConnectionManagerConnection



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/dns/v1/dns_zone.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/dns/v1/dns_zone.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"yandex/cloud/dns/v1/dns_zone.proto\x12\x13yandex.cloud.dns.v1\x1a\x1dyandex/cloud/validation.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x95\x03\n\x07\x44nsZone\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x38\n\x06labels\x18\x06 \x03(\x0b\x32(.yandex.cloud.dns.v1.DnsZone.LabelsEntry\x12\x0c\n\x04zone\x18\x07 \x01(\t\x12\x42\n\x12private_visibility\x18\x08 \x01(\x0b\x32&.yandex.cloud.dns.v1.PrivateVisibility\x12@\n\x11public_visibility\x18\t \x01(\x0b\x32%.yandex.cloud.dns.v1.PublicVisibility\x12\x1b\n\x13\x64\x65letion_protection\x18\n \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x81\x01\n\tRecordSet\x12\x17\n\x04name\x18\x01 \x01(\tB\t\x8a\xc8\x31\x05\x31-254\x12\x16\n\x04type\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04\x31-20\x12\x1d\n\x03ttl\x18\x03 \x01(\x03\x42\x10\xfa\xc7\x31\x0c\x30-2147483647\x12$\n\x04\x64\x61ta\x18\x04 \x03(\tB\x16\x82\xc8\x31\x05\x31-100\x8a\xc8\x31\x05\x31-255\x90\xc8\x31\x01\"=\n\x11PrivateVisibility\x12(\n\x0bnetwork_ids\x18\x01 \x03(\tB\x13\x82\xc8\x31\x05\x30-100\x8a\xc8\x31\x02\x32\x30\x90\xc8\x31\x01\"\x12\n\x10PublicVisibilityBV\n\x17yandex.cloud.api.dns.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/dns/v1;dnsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.dns.v1.dns_zone_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.dns.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/dns/v1;dns'
  _globals['_DNSZONE_LABELSENTRY']._loaded_options = None
  _globals['_DNSZONE_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_RECORDSET'].fields_by_name['name']._loaded_options = None
  _globals['_RECORDSET'].fields_by_name['name']._serialized_options = b'\212\3101\0051-254'
  _globals['_RECORDSET'].fields_by_name['type']._loaded_options = None
  _globals['_RECORDSET'].fields_by_name['type']._serialized_options = b'\212\3101\0041-20'
  _globals['_RECORDSET'].fields_by_name['ttl']._loaded_options = None
  _globals['_RECORDSET'].fields_by_name['ttl']._serialized_options = b'\372\3071\0140-2147483647'
  _globals['_RECORDSET'].fields_by_name['data']._loaded_options = None
  _globals['_RECORDSET'].fields_by_name['data']._serialized_options = b'\202\3101\0051-100\212\3101\0051-255\220\3101\001'
  _globals['_PRIVATEVISIBILITY'].fields_by_name['network_ids']._loaded_options = None
  _globals['_PRIVATEVISIBILITY'].fields_by_name['network_ids']._serialized_options = b'\202\3101\0050-100\212\3101\00220\220\3101\001'
  _globals['_DNSZONE']._serialized_start=124
  _globals['_DNSZONE']._serialized_end=529
  _globals['_DNSZONE_LABELSENTRY']._serialized_start=484
  _globals['_DNSZONE_LABELSENTRY']._serialized_end=529
  _globals['_RECORDSET']._serialized_start=532
  _globals['_RECORDSET']._serialized_end=661
  _globals['_PRIVATEVISIBILITY']._serialized_start=663
  _globals['_PRIVATEVISIBILITY']._serialized_end=724
  _globals['_PUBLICVISIBILITY']._serialized_start=726
  _globals['_PUBLICVISIBILITY']._serialized_end=744
# @@protoc_insertion_point(module_scope)
